package MMM::Report::Console;

use strict;
use base qw(MMM::Report);

=head1 NAME

MMM::Report::Console

=head1 SYNOPSIS

    use MMM::Report::Console;
    my $mmm = MMM::Report::Console->new( configfile => $file );
    $mmm->load_queue();
    $mmm->report();

=head1 DESCRIPTION

Produce textual report of MMM work done.

=head1 SEE ALSO

L<MMM>
L<MMM::Report>
L<MMM::Html>

=cut

sub body {
    my ($self) = @_;
    foreach my $q ( $self->queues() ) {
        $q->is_disable and next;
        my %info    = $q->lastrun_info();
        my %running = $q->running_info();
        my %success = $q->lastsuccess_info();
        printf( "%s (%s):\n",
            $q->dest(),
            keys %running ? sprintf( 'Running for %ds', $running{duration} )
            : $q->next_run_time - scalar(time) > 0
            ? sprintf( 'In %ds', $q->next_run_time - scalar(time) )
            : 'ASAP' );
        if (%info) {
            printf(
                "\tlast run: %s %s (%ds)\n",
                $info{status} ? 'Failed' : 'Succefully',
                scalar( gmtime( $info{start} ) ),
                $info{duration},
            );
        }
        else {
            print "Never run\n";
        }
        if ( $info{status} && keys %success ) {
            printf( "\tlast success: %s\n", scalar( gmtime( $success{start} ) ) );
        }
        print "\n";
    }
}

1;

=head1 AUTHOR

Olivier Thauvin <nanardon@nanardon.zarb.org>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2006 Olivier Thauvin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

=cut

