package MMM::Report::Html;

use strict;
use MMM;
use base qw(MMM::Report);
use CGI;

=head1 NAME

MMM::Report::Html

=head1 SYNOPSIS

    use MMM::Report::Html;
    my $mmm = MMM::Report::Html->new( configfile => $file );
    $mmm->load_queue();
    $mmm->report();

=head1 DESCRIPTION

Produce html report of MMM work done.

=head1 SEE ALSO

L<MMM>
L<MMM::Report>
L<MMM::Console>

=cut

sub new {
    my ( $class, @args ) = @_;
    my $me = $class->SUPER::new(@args) or return;
    $me->{cgi} = new CGI;
    bless( $me, $class );
}

sub header {
    my ($self) = @_;
    print $self->{cgi}->start_html( -title => 'MMM report page' ),
      $self->{cgi}->h1( { align => 'center' }, 'MMM report page' ), "\n";
    printf "<p>Page generated at %s</p>\n",
      CGI::escapeHTML( scalar( gmtime() ) );
}

sub footer {
    my ($self) = @_;
    print <<EOF;
<hr width="20%" align="left">
<p>Generated by <a href="http://mmm.zarb.org/">MMM $MMM::VERSION</a></p>
EOF
    print $self->{cgi}->end_html();
}

sub body {
    my ($self) = @_;
    foreach my $q (
        sort {
                 $a->source cmp $b->source
              || $a->val('subdir') cmp $b->val('subdir')
        } $self->queues()
      )
    {
        $q->is_disable and next;
        my %info    = $q->lastrun_info();
        my %running = $q->running_info();
        my %success = $q->lastsuccess_info();
        print $self->{cgi}
          ->h3( sprintf( '%s::%s', $q->source(), $q->val('subdir') || '' ) ),
          "\n";

        if ( $q->val('announce') ) {
            printf( "<p>%s</p>\n", $q->val('announce') );
        }

        print $self->{cgi}->start_ul();
        print $self->{cgi}->li(
            keys %running ? sprintf( 'Running for %ds', $running{duration} )
            : $q->next_run_time - scalar(time) > 0
            ? sprintf( 'Will be run in %ds', $q->next_run_time - scalar(time) )
            : 'Is waiting next process'
        );
        if ( keys %info ) {
            print $self->{cgi}->li(
                sprintf(
                    "Last run: <strong>%s</strong> at %s (took %ds)\n",
                    $info{status} ? 'Failed' : 'Succefully',
                    scalar( gmtime( $info{end} ) ),
                    $info{duration},
                )
            );
        }
        else {
            print $self->{cgi}->li("Has been never run yet");
        }
        if ( $info{status} && keys %success ) {
            print $self->{cgi}->li(
                sprintf( "last success end at %s",
                    scalar( gmtime( $success{end} ) ) )
            );
        }
        print $self->{cgi}->end_ul(), "<br />\n";
    }
}

1;

=head1 AUTHOR

Olivier Thauvin <nanardon@nanardon.zarb.org>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2006 Olivier Thauvin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

=cut
